#.------------------------------------------------------------,
#| Compact Flash Builder - IBM Embedded Linux Network Station |
#|                                                            |
#| This code originally developed by:                         |
#| Ryan Harper and Christopher Glendenning                    |
#| March, April 2000                                          |
#|                                                            |
#| Filename: menubar.tcl                                      |
#| Last Modified: April 26, 2000 by Ryan Harper               |
#| Changes:  added View Log option under Help                 |
#| Description: Builds the menuing system. Implemented as of  |
#|     version 2.3                                            |
#`------------------------------------------------------------'

#Builds the menuing system for the Compact Flash Builder
#  (CFBuilder). This menuing system is being implemented
#  as of version 2.1 of the program.
#Remove the procedure MOO and the -command{MOO} calls for
#  all submenu options should be replaced with the appropriate
#  proc call for the intended wizard page to be displayed.
#Chris Glendenning 4/7/2000
#Ryan Harper Hacking 04.05.00


#-------------------MENU BAR----------------------------------------------- 

proc buildMenus {} {
    global CFBUILD_DIR_NO_SLASH
    global lh
    puts $lh [format "%s" "Creating Menu (buildMenus)"]
    flush $lh
    frame .menubar -height 18 -relief raised -borderwidth 2
    pack .menubar -side top -fill x

    #make background canvas and add logo image
    set c [canvas .c -width 545 -height 195 -relief sunken -bd 2]
    set image [image create photo -file CFBUILDER.GIF]
    $c create image 275 100 -image $image -tags item
    pack .c

    #Create menubutton .menubar.file with submenu .menubar.file.menu
    # --FILE--
    menubutton .menubar.file -text "File" -menu .menubar.file.menu -underline 0
    menu .menubar.file.menu -tearoff 0
    pack .menubar.file -side left

    #Create menubutton .menubar.build with submenu .menubar.build.menu
    # --BUILD--
    menubutton .menubar.build -text "Build" -menu .menubar.build.menu\
      -underline 0
    menu .menubar.build.menu -tearoff 0
    pack .menubar.build -side left

    #Create menubutton .menubar.settings with submenu .menubar.settings.menu
    # --SETTINGS--
    menubutton .menubar.settings -text "Settings" -menu .menubar.settings.menu\
      -underline 0
    menu .menubar.settings.menu -tearoff 0
    pack .menubar.settings -side left

    #Create menubutton .menubar.system with submenu .menubar.system.menu
    # --SYSTEM--
    menubutton .menubar.system -text "System" -menu .menubar.system.menu\
      -underline 0
    menu .menubar.system.menu -tearoff 0
    pack .menubar.system -side left

    #Create menubutton .menubar.utilities with submenu .menubar.utilities.menu
    # --UTILITIES--
    menubutton .menubar.utilities -text "Utilities"\
      -menu .menubar.utilities.menu -underline 0
    menu .menubar.utilities.menu -tearoff 0
    pack .menubar.utilities -side left

    #Create menubutton .menubar.help with submenu .menubar.help.menu
    # --HELP--
    menubutton .menubar.help -text "Help" -menu .menubar.help.menu -underline 0
    menu .menubar.help.menu -tearoff 0
    pack .menubar.help -side right

    #Build the submenus

    #File submenu choices
    # --FILE->EXIT--
    .menubar.file.menu add command -label "Exit" -command {exit} -underline 0\
      -accelerator "Ctrl+X"

    #Build submenu choices
    # --BUILD->IMAGE
    .menubar.build.menu add command -label "Image..."\
      -command {select_packages "0"} -underline 0 -accelerator "Ctrl+I"
    # --BUILD->PACKAGES
    .menubar.build.menu add command -label "Packages..."\
      -command {build_packages "0"} -underline 0 -accelerator "Ctrl+P"

    #Settings submenu choices
    # --SETTINGS->DISPLAY
    .menubar.settings.menu add command -label "Display..."\
      -command {choose_settings "0"} -underline 0 -accelerator "Ctrl+D"
    # --SETTINGS->MANAGEMENT
    .menubar.settings.menu add command -label "Management..."\
      -command {choose_settings "0"} -underline 0 -accelerator "Ctrl+M"
    # --SETTINGS->NETWORK
    #      .menubar.settings.menu add command -label "Network..."\
      -command {MOO}  #	 -underline 0 -accelerator "Ctrl+N"

    #System submenu choices
    # --SYSTEM->Run Wizard
    .menubar.system.menu add command -label "Run Wizard..." -command {intro\
      "1"} -underline 0 -accelerator "Ctrl+W"


    #Utilities submenu choices
    # --UTILITIES->BACKUP
    .menubar.utilities.menu add command -label "Backup & Restore..."\
      -command {backup_restore "0"} -underline 0 -accelerator "Ctrl+B"
    # --UTILITIES->FORMAT
    #      .menubar.utilities.menu add command -label "Format..."\
      -command {MOO}  #	 -underline 0 -accelerator "Ctrl+F"
    #      # --UTILITIES->MOUNT
    #      .menubar.utilities.menu add command -label "Mount..."\
      -command {MOO}  #	 -underline 0 -accelerator "Ctrl+U"
    # --UTILITIES->PARTITION
    .menubar.utilities.menu add command -label "Partition..."\
      -command {create_partition "0"} -underline 0 -accelerator "Ctrl+R"

    #Help submenu choices
    # --HELP->ABOUT
    .menubar.help.menu add command -label "About" -command {showAbout}\
      -underline 0 -accelerator "F1"
    .menubar.help.menu add command -label "View Log File" -command {view_log}\
      -underline 0 -accelerator "F2"
    .menubar.help.menu add command -label "View License" -command\
      {show_help_file "$CFBUILD_DIR_NO_SLASH/IPL" "IBM Corporation License"}\
      -underline 0 -accelerator "F3"


    if {[file exists /root/IBM/RunCFWiz]==0} {
	wm iconify .
	intro "1"
    }

}
#----------------------End MenuBar ---------------------------
