#.------------------------------------------------------------,
#| Compact Flash Builder - IBM Embedded Linux Network Station |
#|                                                            |
#| This code originally developed by:                         |
#| Ryan Harper and Christopher Glendenning                    |
#| March, April 2000                                          |
#|                                                            |
#| Filename: wiz_settings.tcl                                 |
#| Last Modified: April 7, 2000 by Chris Glendenning          |
#| Changes:                                                   |
#| Description: allows user to customize settings including   |
#|     sound, display resolution and management               |
#`------------------------------------------------------------'

proc choose_settings {show_next_back} {
    check_for_win {.win}
    global soundMaster
    global res
    global depth
    global clientServerConfigure
    global clientServerIP
    global clientROMFlash
    global clientCompactFlash


    if {[winfo exists .win]} {
	wm deiconify .win
	return
    }

    set win [toplevel .win -width 500 -height 300]
    wm title .win {IBM Linux Setup - Compact Flash Image Setup}
    wm geometry .win 500x300+312+134
    wm resizable .win 0 0
    centerwin {.win}


    frame .win.left -width 200 -height 300
    frame .win.left.sep -width 2 -height 300 -borderwidth 2 -relief sunken
    frame .win.right -width 300 -height 250
    frame .win.rightbottom -width 300 -height 50
    frame .win.right.sep -width 300 -height 2 -borderwidth 2 -relief sunken

    place .win.left -x 0 -y 0
    place .win.left.sep -x 160 -y 0
    place .win.right -x 180 -y 0
    place .win.right.sep -x 0 -y 245
    place .win.rightbottom -x 180 -y 250

    if {$show_next_back} {
	button .win.next -text {Next >} -command {ChangePage "backup_restore"\
	  "1"}
	button .win.back -text {< Back} -command {ChangePage "select_packages"\
	  "1"}
	place .win.back -x 8 -y 260
	place .win.next -x 85 -y 260
    }

    proc config_display {} {
	global soundMaster
	global res
	global depth
	global clientServerConfigure
	global clientServerIP
	global clientROMFlash
	global clientCompactFlash

	if {[winfo exists .win.right.f_setup]} {
	    destroy .win.right.f_setup
	}

	frame .win.right.f_setup -width 300 -height 250
	place .win.right.f_setup -x 0 -y 0

	label .win.right.f_setup.l_setup -justify "left" -text " Choose a\
	  display resolution and depth."

	place .win.right.f_setup.l_setup -x 10 -y 20
	label .win.right.f_setup.l_resolution -text "Resolution:"
	place .win.right.f_setup.l_resolution -x 10 -y 80
	radiobutton .win.right.f_setup.640 -variable res -value "640"\
	  -text "640x480"
	radiobutton .win.right.f_setup.800 -variable res -value "800"\
	  -text "800x600"
	radiobutton .win.right.f_setup.1024 -variable res -value "1024"\
	  -text "1024x768"
	radiobutton .win.right.f_setup.1280 -variable res -value "1280"\
	  -text "1280x1024"

	place .win.right.f_setup.640 -x 100 -y 80
	place .win.right.f_setup.800 -x 100 -y 100
	place .win.right.f_setup.1024 -x 100 -y 120
	place .win.right.f_setup.1280 -x 100 -y 140


	label .win.right.f_setup.l_depth -text "Depth:"
	place .win.right.f_setup.l_depth -x 10 -y 180

	radiobutton .win.right.f_setup.8bit -variable depth -value "8"\
	  -text "8 bit"
	radiobutton .win.right.f_setup.16bit -variable depth -value "16"\
	  -text "16 bit"

	place .win.right.f_setup.8bit -x 100 -y 180
	place .win.right.f_setup.16bit -x 100 -y 200


	return
    }

    proc config_sound {} {
	global soundMaster
	global res
	global depth
	global clientServerConfigure
	global clientServerIP
	global clientROMFlash
	global clientCompactFlash

	set mastervolume $soundMaster

	if {[winfo exists .win.right.f_setup]} {
	    destroy .win.right.f_setup
	}

	proc AdjustVolume args {
	    global mastervolume
	    global soundMaster
	    exec "/IBM/volume" $mastervolume
	    set soundMaster $mastervolume
	}

	frame .win.right.f_setup -width 300 -height 250
	place .win.right.f_setup -x 0 -y 0
	label .win.right.f_setup.l_setup -justify "left" -text " Set the\
	  Master Volume."
	place .win.right.f_setup.l_setup -x 10 -y 20
	label .win.right.f_setup.l_volume -justify "left" -text "Master Volume"
	place .win.right.f_setup.l_volume -x 10 -y 80
	scale .win.right.f_setup.scale -orient vertical -length 150 -from 100\
	  -to 0 -tickinterval 50 -variable mastervolume -command AdjustVolume
	place .win.right.f_setup.scale -x 140 -y 80
	update

    }

    proc config_management {} {
	global soundMaster
	global res
	global depth
	global clientServerConfigure
	global clientServerIP
	global clientROMFlash
	global clientCompactFlash

	if {[winfo exists .win.right.f_setup]} {
	    destroy .win.right.f_setup
	}

	frame .win.right.f_setup -width 300 -height 250
	place .win.right.f_setup -x 0 -y 0

	if {$soundMaster == 0} {
	    set soundMaster "50"
	}


	label .win.right.f_setup.l_setup -justify "left" -text " To enable\
	  management, select the Enable\n Management box, and enter the server\
	  IP."

	place .win.right.f_setup.l_setup -x 10 -y 20

	checkbutton .win.right.f_setup.manage -variable clientServerConfigure\
	  -onvalue 1 -offvalue 0 -text "Enable Management"
	place .win.right.f_setup.manage -x 50 -y 110

	entry .win.right.f_setup.box1 -width 15
	place .win.right.f_setup.box1 -x 65 -y 140

	.win.right.f_setup.box1 insert 0 $clientServerIP
	.win.right.f_setup.box1 select range 0 [string length $clientServerIP]
	focus .win.right.f_setup.box1

	bind .win.right.f_setup.box1 <KeyPress> {
	    if {![regexp "\[0-9\b.\n\]" "%A"]} {
		bell
		break
	    }
	}

    }

    proc save_all args {
	global soundMaster
	global res
	global depth
	global clientServerConfigure
	global clientServerIP
	global clientROMFlash
	global clientCompactFlash

	if {[winfo exists .win.right.f_setup.box1]} {
	    set clientServerIP [.win.right.f_setup.box1 get]
	} {
	    set clientServerIP "0.0.0.0"
	}


	SaveSetupInfo $soundMaster $res $depth $clientServerConfigure\
	  $clientServerIP $clientROMFlash $clientCompactFlash
	destroy .win.right.f_setup
	.win.right.l_setup configure -text " Your changes have been saved,\
	  click the\n buttons on the left to finish customizing\n or click\
	  Next to continue."
	raise .win.right.l_setup

    }

    label .win.left.l_configure -text "Configure: "
    button .win.left.b_display -width 15 -text "Display" -command config_display
    button .win.left.b_sound -width 15 -text "Sound" -command config_sound
    button .win.left.b_management -width 15 -text "Management"\
      -command config_management

    place .win.left.l_configure -x 10 -y 20
    place .win.left.b_display -x 10 -y 70
    place .win.left.b_sound -x 10 -y 120
    place .win.left.b_management -x 10 -y 170

    label .win.right.l_setup -justify "left" -text " To configure the Compact\
      Flash Image, click\n the buttons on the left."
    place .win.right.l_setup -x 10 -y 20
    button .win.rightbottom.b_save -width 15 -text "Save" -command save_all
    place .win.rightbottom.b_save -x 80 -y 10

}


proc SaveSetupInfo args {
    global soundMaster
    global res
    global depth
    global clientServerConfigure
    global clientServerIP
    global clientROMFlash
    global clientCompactFlash

    set filename "/mnt/hd2/IBM/IBMSetupInformationBlock"
    set fd [open $filename w]
    fconfigure $fd
    puts $fd [format "%s=%s" "soundmaster" $soundMaster]
    puts $fd [format "%s=%s" "displayresolution" $res]
    puts $fd [format "%s=%s" "displaycolor" $depth]
    puts $fd [format "%s=%s" "clientserverconfigure" $clientServerConfigure]
    puts $fd [format "%s=%s" "clientserverip" $clientServerIP]
    puts $fd [format "%s=%s" "clientromflash" $clientROMFlash]
    puts $fd [format "%s=%s" "clientcompactflash" $clientCompactFlash]
    close $fd
    exec "/bin/sync"

    set filename1 "/mnt/hd2/IBM/NetworkAddresses"
    set fd1 [open $filename1 w]
    fconfigure $fd1
    puts $fd1 [format "%s=%s" "bootprotocol" "dhcp"]
    puts $fd1 [format "%s=%s" "ip" "0.0.0.0"]
    puts $fd1 [format "%s=%s" "gateway" "0.0.0.0"]
    puts $fd1 [format "%s=%s" "subnetmask" "0.0.0.0"]
    puts $fd1 [format "%s=%s" "nameserver1" "0.0.0.0"]
    puts $fd1 [format "%s=%s" "nameserver2" "0.0.0.0"]
    puts $fd1 [format "%s=%s" "nameserver3" "0.0.0.0"]
    puts $fd1 [format "%s=%s" "hostname" ""]
    puts $fd1 [format "%s=%s" "domainname" ""]
    close $fd1
    exec "/bin/sync"

}
